
# Slot: name




URI: [linkml:schema_definition_name](https://w3id.org/linkml/schema_definition_name)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>1..1</sub> [Ncname](types/Ncname.md)

## Parents

 *  is_a: [name](name.md)

## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
